@@ -19,19 +19,21 @@
 
 #include "../engines.h"
 
-struct gocryptfs : public engines::engine
+class gocryptfs : public engines::engine
 {
+public:
 	gocryptfs() ;
 
-	void updateMountOptions( engines::engine::options&,
-				 QString& configFilePath ) const override ;
+	void updateOptions( engines::engine::options& ) const override ;
 
 	engines::engine::status errorCode( const QString& e,int s ) const override ;
 
-	engines::engine::args command( const QString& password,
+	engines::engine::args command( const QByteArray& password,
 				       const engines::engine::cmdArgsList& args ) const override ;
 
-	QString installedVersionString() const override ;
+	const QString& installedVersionString() const override ;
 
 	void GUICreateOptionsinstance( QWidget * parent,engines::engine::function ) const override ;
+private:
+	engines::version m_version ;
 } ;
