@@ -25,6 +25,8 @@ static engines::engine::BaseOptions _setOptions()
 {
 	engines::engine::BaseOptions s ;
 
+	s.backendTimeout              = 0 ;
+	s.takesTooLongToUnlock        = false ;
 	s.supportsMountPathsOnWindows = false ;
 	s.autorefreshOnMountUnMount   = true ;
 	s.backendRequireMountPath     = true ;
@@ -51,11 +53,12 @@ static engines::engine::BaseOptions _setOptions()
 	return s ;
 }
 
-securefs::securefs() : engines::engine( _setOptions() )
+securefs::securefs() : engines::engine( _setOptions() ),
+	m_version( [ this ]{ return this->baseInstalledVersionString( "version",true,1,0 ) ; } )
 {
 }
 
-engines::engine::args securefs::command( const QString& password,
+engines::engine::args securefs::command( const QByteArray& password,
 					 const engines::engine::cmdArgsList& args ) const
 {
 	Q_UNUSED( password )
@@ -113,9 +116,9 @@ engines::engine::status securefs::errorCode( const QString& e,int s ) const
 	}
 }
 
-QString securefs::installedVersionString() const
+const QString& securefs::installedVersionString() const
 {
-	return this->baseInstalledVersionString( "version",true,1,0 ) ;
+	return m_version.get() ;
 }
 
 void securefs::GUICreateOptionsinstance( QWidget * parent,engines::engine::function function ) const
