@@ -45,28 +45,28 @@ unknown::unknown() : engines::engine( _setOptions() )
 {
 }
 
-engines::engine::args unknown::command( const QString& password,
+engines::engine::args unknown::command( const QByteArray& password,
 					const engines::engine::cmdArgsList& args ) const
 {
-	Q_UNUSED( password ) ;
-	Q_UNUSED( args ) ;
+	Q_UNUSED( password )
+	Q_UNUSED( args )
 	return {} ;
 }
 
 engines::engine::status unknown::errorCode( const QString& e,int s ) const
 {
-	Q_UNUSED( e ) ;
-	Q_UNUSED( s ) ;
+	Q_UNUSED( e )
+	Q_UNUSED( s )
 	return engines::engine::status::backendFail ;
 }
 
-QString unknown::installedVersionString() const
+const QString& unknown::installedVersionString() const
 {
-	return {} ;
+	return m_version.get() ;
 }
 
 void unknown::GUICreateOptionsinstance( QWidget * parent,engines::engine::function function ) const
 {
-	Q_UNUSED( parent ) ;
-	Q_UNUSED( function ) ;
+	Q_UNUSED( parent )
+	Q_UNUSED( function )
 }
