@@ -21,6 +21,7 @@
 
 #include "utility.h"
 #include "settings.h"
+#include "crypto.h"
 
 #include <QDir>
 #include <QFile>
@@ -45,11 +46,15 @@ static utility::result< QString > _config_path()
 
 static QString _create_path( const QString& m,const favorites::entry& e )
 {
-	auto a = utility::split( e.volumePath,'/' ).last() ;
-	auto b = a + e.mountPointPath ;
-	auto c = QCryptographicHash::hash( b.toLatin1(),QCryptographicHash::Sha256 ) ;
+	auto a = utility::split( e.volumePath,'@' ).last() ;
 
-	return m + a + "-" + c.toHex() + ".json" ;
+	a = utility::split( a,'/' ).last() ;
+
+	a.replace( ":","" ) ;
+
+	auto b = a + e.mountPointPath ;
+
+	return m + a + "-" + crypto::sha256( b ) + ".json" ;
 }
 
 static QString _create_path( const favorites::entry& e )
@@ -58,11 +63,7 @@ static QString _create_path( const favorites::entry& e )
 
 	if( s.has_value() ){
 
-		auto a = utility::split( e.volumePath,'/' ).last() ;
-		auto b = a + e.mountPointPath ;
-		auto c = QCryptographicHash::hash( b.toLatin1(),QCryptographicHash::Sha256 ) ;
-
-		return s.value() + a + "-" + c.toHex() + ".json" ;
+		return _create_path( s.value(),e ) ;
 	}else{
 		return {} ;
 	}
@@ -122,6 +123,13 @@ static void _move_favorites_to_new_system( const QStringList& m )
 	favorites::instance().add( s ) ;
 }
 
+static void _log_error( const QString& msg,const QString& path )
+{
+	auto a = "\nFailed to parse file for reading: " + path ;
+
+	utility::debug::showDebugWindow( msg + a ) ;
+}
+
 static void _add_entries( std::vector< favorites::entry >& e,const QString& path )
 {
 	try {
@@ -148,21 +156,28 @@ static void _add_entries( std::vector< favorites::entry >& e,const QString& path
 
 	}catch( const SirikaliJson::exception& e ){
 
-		utility::debug::cout() << e.what() ;
-		utility::debug::cout() << "Failed to parse file for reading: " + path ;
+		_log_error( e.what(),path ) ;
+
+	}catch( const std::exception& e ){
+
+		_log_error( e.what(),path ) ;
+
+	}catch( ... ){
+
+		_log_error( "Unknown error has occured",path ) ;
 	}
 }
 
 std::vector<favorites::entry> favorites::readFavorites() const
 {
-	auto m = _config_path() ;
+	const auto m = _config_path() ;
 
 	if( !m.has_value() ){
 
 		return {} ;
 	}
 
-	auto a = m.value() ;
+	const auto& a = m.value() ;
 
 	const auto s = QDir( a ).entryList( QDir::Filter::Files | QDir::Filter::Hidden ) ;
 
@@ -226,36 +241,52 @@ favorites::error favorites::add( const favorites::entry& e )
 		return error::FAILED_TO_CREATE_ENTRY ;
 	}
 
-	SirikaliJson json ;
-
-	json[ "volumePath" ]           = e.volumePath ;
-	json[ "mountPointPath" ]       = e.mountPointPath ;
-	json[ "configFilePath" ]       = e.configFilePath ;
-	json[ "idleTimeOut" ]          = e.idleTimeOut ;
-	json[ "mountOptions" ]         = e.mountOptions ;
-	json[ "preMountCommand" ]      = e.preMountCommand ;
-	json[ "postMountCommand" ]     = e.postMountCommand ;
-	json[ "preUnmountCommand" ]    = e.preUnmountCommand ;
-	json[ "postUnmountCommand" ]   = e.postUnmountCommand ;
-	json[ "reverseMode" ]          = e.reverseMode ;
-	json[ "volumeNeedNoPassword" ] = e.volumeNeedNoPassword ;
-
-	favorites::triState::writeTriState( json,e.readOnlyMode,"mountReadOnly" ) ;
-	favorites::triState::writeTriState( json,e.autoMount,"autoMountVolume" ) ;
-
 	auto a = _create_path( m.value(),e ) ;
 
-	if( utility::pathExists( a ) ){
+	try{
+		SirikaliJson json ;
 
-		return error::ENTRY_ALREADY_EXISTS ;
-	}else{
-		if( json.toFile( a ) ){
+		json[ "volumePath" ]           = e.volumePath ;
+		json[ "mountPointPath" ]       = e.mountPointPath ;
+		json[ "configFilePath" ]       = e.configFilePath ;
+		json[ "idleTimeOut" ]          = e.idleTimeOut ;
+		json[ "mountOptions" ]         = e.mountOptions ;
+		json[ "preMountCommand" ]      = e.preMountCommand ;
+		json[ "postMountCommand" ]     = e.postMountCommand ;
+		json[ "preUnmountCommand" ]    = e.preUnmountCommand ;
+		json[ "postUnmountCommand" ]   = e.postUnmountCommand ;
+		json[ "reverseMode" ]          = e.reverseMode ;
+		json[ "volumeNeedNoPassword" ] = e.volumeNeedNoPassword ;
 
-			return error::SUCCESS ;
+		favorites::triState::writeTriState( json,e.readOnlyMode,"mountReadOnly" ) ;
+		favorites::triState::writeTriState( json,e.autoMount,"autoMountVolume" ) ;
+
+		if( utility::pathExists( a ) ){
+
+			return error::ENTRY_ALREADY_EXISTS ;
 		}else{
-			return error::FAILED_TO_CREATE_ENTRY ;
+			if( json.toFile( a ) ){
+
+				return error::SUCCESS ;
+			}else{
+				return error::FAILED_TO_CREATE_ENTRY ;
+			}
 		}
-	}	
+
+	}catch( const SirikaliJson::exception& e ){
+
+		_log_error( e.what(),a ) ;
+
+	}catch( const std::exception& e ){
+
+		_log_error( e.what(),a ) ;
+
+	}catch( ... ){
+
+		_log_error( "Unknown error has occured",a ) ;
+	}
+
+	return error::FAILED_TO_CREATE_ENTRY ;
 }
 
 void favorites::replaceFavorite( const favorites::entry& old,const favorites::entry& New )
