@@ -151,6 +151,7 @@ public:
 	bool allowExternalToolsToReadPasswords() ;
 	void setDefaultMountPointPrefix( const QString& ) ;
 	bool startMinimized() ;
+	bool passWordIsUTF8Encoded() ;
 	void setStartMinimized( bool ) ;
 	void setFileManager( const QString& ) ;
 	QString preUnMountCommand() ;
@@ -203,7 +204,6 @@ public:
 	QString applicationName( void ) ;
 	int readPasswordMaximumLength() ;
 	bool unMountVolumesOnLogout( void ) ;
-	bool requirePolkitOnFsCryptUnmount( void ) ;
 private:
 	QSettings m_settings ;
 };
