@@ -89,6 +89,7 @@ sirikali::sirikali() :
 	m_signalHandler( this,this->getEmergencyShutDown() )
 {
 	utility::setMainQWidget( this ) ;
+	favorites::instance().updateFavorites() ;
 }
 
 std::function< void( systemSignalHandler::signal ) > sirikali::getEmergencyShutDown()
@@ -261,21 +262,25 @@ void sirikali::setUpApp( const QString& volume )
 
 		const auto& engines = engines::instance() ;
 
-		for( const auto& it : engines.supported() ){
+		for( const auto& it : engines.supportedEngines() ){
 
-			auto ac = m->addAction( it ) ;
+			auto name = it->name() ;
 
-			ac->setObjectName( it ) ;
+			name.replace( 0,1,name.at( 0 ).toUpper() ) ;
 
-			if( engines.getByName( it ).isNotInstalled() ){
+			auto ac = m->addAction( name ) ;
+
+			ac->setObjectName( name ) ;
+
+			if( it->isNotInstalled() ){
 
 				ac->setEnabled( false ) ;
 
-				if( it == "Ecryptfs" ){
+				if( name == "Ecryptfs" ){
 
 					ac->setText( tr( "%1 Is Not Installed" ).arg( "Ecryptfs-simple" ) ) ;
 				}else{
-					ac->setText( tr( "%1 Is Not Installed" ).arg( it ) ) ;
+					ac->setText( tr( "%1 Is Not Installed" ).arg( name ) ) ;
 				}
 			}
 		}
@@ -318,7 +323,7 @@ void sirikali::setUpApp( const QString& volume )
 
 	QTimer::singleShot( settings::instance().checkForUpdateInterval(),this,SLOT( autoUpdateCheck() ) ) ;
 
-	if( utility::debugEnabled() || utility::debugFullEnabled() ){
+	if( utility::debugEnabled() ){
 
 		this->showDebugWindow() ;
 	}
@@ -501,17 +506,17 @@ static void _connect_to_ssh_server( QWidget * parent,const favorites::entry& ent
 {
 	auto s = siritask::encryptedFolderMount( entry ) ;
 
-	if( s.cmdStatus() == engines::engine::status::sshfsNotFound ){
+	if( s == engines::engine::status::sshfsNotFound ){
 
 		auto e = QObject::tr( "Failed To Complete The Request.\nSshfs Executable Could Not Be Found." ) ;
 
 		DialogMsg( parent ).ShowUIOK( QObject::tr( "ERROR" ),e ) ;
 
-	}else if( s.cmdStatus() != engines::engine::status::success ){
+	}else if( s != engines::engine::status::success ){
 
 		auto e = QObject::tr( "Failed To Connect To \"%1\" And Below Log was Generated By The Backend.\n" ).arg( entry.volumePath ) ;
 
-		e += "\n----------------------------------------\n" + s.cmdStatus().toMiniString() ;
+		e += "\n----------------------------------------\n" + s.toMiniString() ;
 
 		DialogMsg( parent ).ShowUIOK( QObject::tr( "ERROR" ),e ) ;
 	}
@@ -553,7 +558,9 @@ void sirikali::favoriteClicked( QAction * ac )
 
 				if( _found( it ) ){
 
-					auto s = siritask::mountEngine( it.first.volumePath,QString() ).engine().name() ;
+					siritask::mount m{ it.first.volumePath,QString(),siritask::Engine() } ;
+
+					auto s = siritask::mountEngine( m ).get().name() ;
 
 					if( it.first.volumeNeedNoPassword && s == "sshfs" ){
 
@@ -649,8 +656,8 @@ void sirikali::polkitFailedWarning()
 
 void sirikali::start( const QStringList& l )
 {
-	utility::enableDebug( l.contains( "--debug" ) ) ;
-	utility::enableFullDebug( l.contains( "--debug-full" ) ) ;
+	utility::enableDebug( l.contains( "--debug" ) ) ;	
+	utility::enableDebug( l.contains( "--debug-full" ) ) ;
 
 	m_startHidden  = l.contains( "-e" ) ;
 
@@ -735,7 +742,7 @@ void sirikali::cliCommand( const QStringList& l )
 
 			if( a == volume || b == volume ){
 
-				if( siritask::encryptedFolderUnMount( a,b,c,5 ).success() ){
+				if( siritask::encryptedFolderUnMount( { a,b,c,5 } ).success() ){
 
 					siritask::deleteMountFolder( b ) ;
 
@@ -782,9 +789,9 @@ void sirikali::unlockVolume( const QStringList& l )
 
 		this->closeApplication( 1,tr( "ERROR: Volume Path Not Given." ) ) ;
 	}else{
-		auto _unlockVolume = [ & ]( const QString& key ){
+		auto _unlockVolume = [ & ]( const QByteArray& key ){
 
-			auto m = [ & ]()->QString{
+			auto m = [ & ](){
 
 				if( mountPath.isEmpty() ){
 
@@ -798,23 +805,24 @@ void sirikali::unlockVolume( const QStringList& l )
 
 			m_mountInfo.announceEvents( false ) ;
 
-			engines::engine::options s( volume,m,key,idleTime,cPath,QString(),mode,reverse,mOpt,QString() ) ;
+			engines::engine::options s( volume,m,key,idleTime,cPath,mode,reverse,mOpt,QString() ) ;
 
 			auto e = siritask::encryptedFolderMount( s ) ;
 
-			if( e.cmdStatus() == engines::engine::status::success ){
+			if( e == engines::engine::status::success ){
 
 				//this->openMountPointPath( m ) ;
 
 				this->closeApplication( 0 ) ;
 			}else{
+				utility::debug::cerr() << e.toString() ;
 				this->closeApplication( 1 ) ;
 			}
 		} ;
 
 		if( backEnd == "stdin" ){
 
-			return _unlockVolume( [ & ]()->QString{
+			return _unlockVolume( [ & ](){
 
 				auto e = utility::readPassword() ;
 
@@ -883,7 +891,7 @@ void sirikali::unlockVolume( const QStringList& l )
 
 				this->closeApplication( 1,tr( "ERROR: Key Not Found In The Backend." ) ) ;
 			}else{
-				_unlockVolume( w.key ) ;
+				_unlockVolume( w.key.toUtf8() ) ;
 			}
 		}else{
 			this->closeApplication( 1,tr( "ERROR: Failed To Unlock Requested Backend." ) ) ;
@@ -992,14 +1000,14 @@ favorites::volumeList sirikali::autoUnlockVolumes( favorites::volumeList l,bool
 			}else{
 				auto s = siritask::encryptedFolderMount( { e.first,key } ) ;
 
-				if( s.cmdStatus() == engines::engine::status::success ){
+				if( s == engines::engine::status::success ){
 
 					if( autoOpenFolderOnMount ){
 
 						this->openMountPointPath( e.first.mountPointPath ) ;
 					}
 
-					if( s.backendDoesNotAutoRefresh() ){
+					if( !s.engine().autorefreshOnMountUnMount() ){
 
 						this->updateList() ;
 					}
@@ -1455,30 +1463,8 @@ void sirikali::updateFavoritesInContextMenu()
 		}
 		int row( const QString& e )
 		{
-			auto x = utility::policyString() ;
-			auto y = "\n" + utility::commentString() ;
-
 			auto a = utility::split( e,'\n' ) ;
 
-			if( e.startsWith( x ) && e.contains( y ) ){
-
-				/*
-				 * we have an fscrypt volume, cipherpath for this volume
-				 * is in a format of "Policy:xys\nComment:abc" and below
-				 * code combines these two into a single entry since
-				 * variable "a" above split it into two.
-				 */
-				if( a.size() > 1 ){
-
-					auto m = a.at( 0 ) + "\n" + a.at( 1 ) ;
-
-					a.removeAt( 0 ) ;
-					a.removeAt( 0 ) ;
-
-					a.insert( 0,m ) ;
-				}
-			}
-
 			if( a.size() == 1 ){
 
 				const auto& m = a.at( 0 ) ;
@@ -1673,11 +1659,6 @@ void sirikali::updateList( const volumeInfo& entry )
 		if( row == -1 ){
 
 			row = tablewidget::addRow( table ) ;
-		}else{
-			if( entry.fileSystem() == "fscrypt" ){
-
-				row = tablewidget::addRow( table ) ;
-			}
 		}
 
 		tablewidget::updateRow( table,entry.mountInfo().minimalList(),row,this->font() ) ;
@@ -1686,9 +1667,9 @@ void sirikali::updateList( const volumeInfo& entry )
 	}
 }
 
-siritask::taskResult sirikali::unMountVolume( const sirikali::mountedEntry& e )
+engines::engine::cmdStatus sirikali::unMountVolume( const sirikali::mountedEntry& e )
 {
-	auto s = siritask::encryptedFolderUnMount( e.cipherPath,e.mountPoint,e.volumeType,5 ) ;
+	auto s = siritask::encryptedFolderUnMount( { e.cipherPath,e.mountPoint,e.volumeType,5 } ) ;
 
 	if( s.success() && s.engine().backendRequireMountPath() ){
 
@@ -1720,14 +1701,19 @@ void sirikali::pbUmount()
 
 		if( s.success() ){
 
-			if( s.backendDoesNotAutoRefresh() ){
+			if( !s.engine().autorefreshOnMountUnMount() ){
 
 				this->updateList() ;
 			}
 		}else{
-			DialogMsg( this ).ShowUIOK( tr( "ERROR" ),tr( "Failed To Unmount %1 Volume" ).arg( type ) ) ;
+			DialogMsg( this ).ShowUIOK( tr( "ERROR" ),s.toString() ) ;
 
-			this->enableAll() ;
+			if( s == engines::engine::status::failedToUnMount ){
+
+				this->enableAll() ;
+			}else{
+				this->pbUpdate() ;
+			}
 		}
 	}
 }
