@@ -141,83 +141,6 @@ namespace utility2
 
 		utility2::detail::stringListToStrings( s,type_t( 0 ),s.size(),t ... ) ;
 	}
-
-	static inline QStringList executableSearchPaths()
-	{
-		const auto a = QDir::homePath().toLatin1() ;
-		const auto b = a + "/bin/" ;
-		const auto c = a + "/.bin/" ;
-
-#ifdef Q_OS_WIN
-		return { b.constData(),c.constData() } ;
-#else
-		return { "/usr/local/bin/",
-			"/usr/local/sbin/",
-			"/usr/bin/",
-			"/usr/sbin/",
-			"/bin/",
-			"/sbin/",
-			"/opt/local/bin/",
-			"/opt/local/sbin/",
-			"/opt/bin/",
-			"/opt/sbin/",
-			 b.constData(),
-			 c.constData() } ;
-#endif
-	}
-
-	static inline QString executableFullPath( const QString& f,
-						  std::function< QString( const QString& ) > function = nullptr )
-	{
-		if( function ){
-
-			auto s = function( f ) ;
-
-			if( !s.isEmpty() ){
-
-				return s ;
-			}
-		}
-
-		QString e = f ;
-
-		if( e == "ecryptfs" ){
-
-			e = "ecryptfs-simple" ;
-		}
-
-#ifdef Q_OS_WIN
-		if( !e.endsWith( ".exe" ) ){
-
-			e += ".exe" ;
-		}
-#else
-
-#endif
-		QString exe ;
-
-		for( const auto& it : utility2::executableSearchPaths() ){
-
-			exe = it + e ;
-
-			if( QFile::exists( exe ) ){
-
-				return exe ;
-			}
-		}
-
-		return QString() ;
-	}
-
-	class translator
-	{
-	public:
-		void setLanguage( const QByteArray& e ) ;
-		~translator() ;
-	private:
-		void clear( void ) ;
-		QTranslator * m_translator = nullptr ;
-	} ;
 }
 
 #endif
